@@ -53,8 +53,11 @@ class FESReporter(object):
         self.CV_values.append(self.metaD_wrapper.getCollectiveVariables(simulation))
         self.free_energy.append(self.metaD_wrapper.getFreeEnergy())
         fes = self.free_energy[-1].value_in_unit(unit.kilocalorie_per_mole)
-        self.dG_trace.append(calc_dG(fes,order=20))
-        self.coverage_trace.append(calc_coverage(fes))
+        try:
+            self.dG_trace.append(calc_dG(fes,order=20))
+            self.coverage_trace.append(calc_coverage(fes))
+        except:
+            print('failed to calculate dG and/or coverage. This is only available for sims with >1 CV')
 
         # Save coverage, dG, free energy and CV files periodically
         with open(os.path.join(self._out,'dG_trace.pickle'),'wb') as dG_pickle:
